@@ -1,24 +1,11 @@
 /*
     ktnefmessage.cpp
 
-    Copyright (C) 2002 Michael Goffioul <kdeprint@swing.be>
+    SPDX-FileCopyrightText: 2002 Michael Goffioul <kdeprint@swing.be>
 
     This file is part of KTNEF, the KDE TNEF support library/program.
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
  */
 /**
  * @file
@@ -33,6 +20,7 @@
 #include "lzfu.h"
 
 #include <QBuffer>
+#include <QDebug>
 #include <QList>
 
 using namespace KTnef;
@@ -113,7 +101,9 @@ QString KTNEFMessage::rtfString() const
         QBuffer input(&propArray), output(&rtf);
         if (input.open(QIODevice::ReadOnly) &&
                 output.open(QIODevice::WriteOnly)) {
-            KTnef::lzfu_decompress(&input, &output);
+            if (KTnef::lzfu_decompress(&input, &output) == 0) {
+                qWarning() << "Error when decompress data";
+            }
         }
         return QString::fromLatin1(rtf);
     }
